@@ -312,7 +312,7 @@ def _get_socket_opts(keepalive=True,
 
 class Client(object):
     """
-    Crate connection client using crate's HTTP API.
+    Crate connection client using CrateDB's HTTP API.
     """
 
     SQL_PATH = '/_sql?types'
@@ -328,7 +328,7 @@ class Client(object):
                  servers=None,
                  timeout=None,
                  backoff_factor=0,
-                 verify_ssl_cert=False,
+                 verify_ssl_cert=True,
                  ca_cert=None,
                  error_trace=False,
                  cert_file=None,
@@ -544,8 +544,8 @@ class Client(object):
                                        (ts, server, message))
                     else:
                         self._active_servers.append(server)
-                        logger.warn("Restored server %s into active pool",
-                                    server)
+                        logger.warning("Restored server %s into active pool",
+                                       server)
 
             # if none is old enough, use oldest
             if not self._active_servers:
@@ -568,6 +568,15 @@ class Client(object):
         """
         Drop server from active list and adds it to the inactive ones.
         """
+
+        # Try to close resource first.
+        try:
+            self.server_pool[server].close()
+        except Exception as ex:
+            logger.warning("When removing server from active pool, "
+                           "resource could not be closed: %s", ex)
+
+        # Apply bookkeeping.
         try:
             self._active_servers.remove(server)
         except ValueError:
@@ -576,7 +585,7 @@ class Client(object):
             heapq.heappush(self._inactive_servers, (time(), server, message))
             logger.warning("Removed server %s from active pool", server)
 
-        # if this is the last server raise exception, otherwise try next
+        # If this is the last server, raise an exception.
         if not self._active_servers:
             raise ConnectionError(
                 ("No more Servers available, "
